ParseError

Struct ParseError 

pub struct ParseError { /* private fields */ }
The error type returned by the parse functions in this crate.

See ParseError::fmt_with_source for pretty-printing and ParseErrorKind of the different types of errors represented by this struct.

Implementations

Source

impl ParseError

pub fn fmt_with_source(&self, source: &str) -> impl Display

Pretty-prints this error and if applicable, shows where the error occurred in the source.

Must be called with the same source that was used to parse the set.

Examples
use icu_unicodeset_parse::*;

let source = "[[abc]-x]";
let set = parse(source);
assert!(set.is_err());
let err = set.unwrap_err();
assert_eq!(
    err.fmt_with_source(source).to_string(),
    "[[abc]-x← error: unexpected character 'x'"
);
use icu_unicodeset_parse::*;

let source = r"[\N{LATIN CAPITAL LETTER A}]";
let set = parse(source);
assert!(set.is_err());
let err = set.unwrap_err();
assert_eq!(
    err.fmt_with_source(source).to_string(),
    r"[\N← error: unimplemented"
);
pub fn kind(&self) -> ParseErrorKind

Returns the ParseErrorKind of this error.

pub fn offset(&self) -> Option<usize>

Returns the offset of this error in the source string, if it was specified.